@@ -11,7 +11,7 @@ from rich.style import Style
 from typing_extensions import TypedDict
 
 from .._animator import DEFAULT_EASING, Animatable, BoundAnimator, EasingFunction
-from .._types import CallbackType
+from .._types import AnimationLevel, CallbackType
 from ..color import Color
 from ..geometry import Offset, Spacing
 from ._style_properties import (
@@ -369,6 +369,7 @@ class StylesBase(ABC):
         speed: float | None,
         easing: EasingFunction,
         on_complete: CallbackType | None = None,
+        level: AnimationLevel = "full",
     ) -> ScalarAnimation | None:
         if self.node is None:
             return None
@@ -400,6 +401,7 @@ class StylesBase(ABC):
                     if on_complete is not None
                     else None
                 ),
+                level=level,
             )
         return None
 
@@ -1142,6 +1144,7 @@ class RenderStyles(StylesBase):
         delay: float = 0.0,
         easing: EasingFunction | str = DEFAULT_EASING,
         on_complete: CallbackType | None = None,
+        level: AnimationLevel = "full",
     ) -> None:
         """Animate an attribute.
 
@@ -1154,6 +1157,7 @@ class RenderStyles(StylesBase):
             delay: A delay (in seconds) before the animation starts.
             easing: An easing method.
             on_complete: A callable to invoke when the animation is finished.
+            level: Minimum level required for the animation to take place (inclusive).
         """
         if self._animate is None:
             assert self.node is not None
@@ -1168,6 +1172,7 @@ class RenderStyles(StylesBase):
             delay=delay,
             easing=easing,
             on_complete=on_complete,
+            level=level,
         )
 
     def __rich_repr__(self) -> rich.repr.Result:
