@@ -2,11 +2,13 @@ from __future__ import annotations
 
 from typing import Iterable
 
+from rich import terminal_theme
 from rich.console import Console, ConsoleOptions, RenderableType, RenderResult
 from rich.segment import Segment
 from rich.style import Style
 
 from ..color import Color
+from ..filter import ANSIToTruecolor
 
 
 class Tint:
@@ -43,13 +45,15 @@ class Tint:
         style_from_color = Style.from_color
         _Segment = Segment
 
+        truecolor_style = ANSIToTruecolor(terminal_theme.DIMMED_MONOKAI).truecolor_style
+
         NULL_STYLE = Style()
         for segment in segments:
             text, style, control = segment
             if control:
                 yield segment
             else:
-                style = style if style is not None else NULL_STYLE
+                style = truecolor_style(style) if style is not None else NULL_STYLE
                 yield _Segment(
                     text,
                     (
