@@ -7,7 +7,7 @@ from __future__ import annotations
 from rich.console import RenderableType
 
 from ._animator import EasingFunction
-from ._types import CallbackType
+from ._types import AnimationLevel, CallbackType
 from .containers import ScrollableContainer
 from .geometry import Region, Size
 
@@ -119,6 +119,7 @@ class ScrollView(ScrollableContainer):
         easing: EasingFunction | str | None = None,
         force: bool = False,
         on_complete: CallbackType | None = None,
+        level: AnimationLevel = "basic",
     ) -> None:
         """Scroll to a given (absolute) coordinate, optionally animating.
 
@@ -131,6 +132,7 @@ class ScrollView(ScrollableContainer):
             easing: An easing method for the scrolling animation.
             force: Force scrolling even when prohibited by overflow styling.
             on_complete: A callable to invoke when the animation is finished.
+            level: Minimum level required for the animation to take place (inclusive).
         """
 
         self._scroll_to(
@@ -142,6 +144,7 @@ class ScrollView(ScrollableContainer):
             easing=easing,
             force=force,
             on_complete=on_complete,
+            level=level,
         )
 
     def refresh_line(self, y: int) -> None:
